@@ -10,11 +10,17 @@ Usage::
     client: ElasticLoadBalancingClient = boto3.client("elb")
     ```
 """
-import sys
 from typing import Any, Dict, List, Type, overload
 
 from botocore.client import ClientMeta
 
+from mypy_boto3_elb.literals import (
+    AnyInstanceInServiceWaiterName,
+    DescribeAccountLimitsPaginatorName,
+    DescribeLoadBalancersPaginatorName,
+    InstanceDeregisteredWaiterName,
+    InstanceInServiceWaiterName,
+)
 from mypy_boto3_elb.paginator import DescribeAccountLimitsPaginator, DescribeLoadBalancersPaginator
 from mypy_boto3_elb.type_defs import (
     AddAvailabilityZonesOutputTypeDef,
@@ -48,12 +54,6 @@ from mypy_boto3_elb.waiter import (
     InstanceInServiceWaiter,
 )
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
-
-
 __all__ = ("ElasticLoadBalancingClient",)
 
 
@@ -323,7 +323,7 @@ class ElasticLoadBalancingClient:
 
     @overload
     def get_paginator(
-        self, operation_name: Literal["describe_account_limits"]
+        self, operation_name: DescribeAccountLimitsPaginatorName
     ) -> DescribeAccountLimitsPaginator:
         """
         [Paginator.DescribeAccountLimits documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/elb.html#ElasticLoadBalancing.Paginator.DescribeAccountLimits)
@@ -331,30 +331,26 @@ class ElasticLoadBalancingClient:
 
     @overload
     def get_paginator(
-        self, operation_name: Literal["describe_load_balancers"]
+        self, operation_name: DescribeLoadBalancersPaginatorName
     ) -> DescribeLoadBalancersPaginator:
         """
         [Paginator.DescribeLoadBalancers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/elb.html#ElasticLoadBalancing.Paginator.DescribeLoadBalancers)
         """
 
     @overload
-    def get_waiter(
-        self, waiter_name: Literal["any_instance_in_service"]
-    ) -> AnyInstanceInServiceWaiter:
+    def get_waiter(self, waiter_name: AnyInstanceInServiceWaiterName) -> AnyInstanceInServiceWaiter:
         """
         [Waiter.AnyInstanceInService documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/elb.html#ElasticLoadBalancing.Waiter.AnyInstanceInService)
         """
 
     @overload
-    def get_waiter(
-        self, waiter_name: Literal["instance_deregistered"]
-    ) -> InstanceDeregisteredWaiter:
+    def get_waiter(self, waiter_name: InstanceDeregisteredWaiterName) -> InstanceDeregisteredWaiter:
         """
         [Waiter.InstanceDeregistered documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/elb.html#ElasticLoadBalancing.Waiter.InstanceDeregistered)
         """
 
     @overload
-    def get_waiter(self, waiter_name: Literal["instance_in_service"]) -> InstanceInServiceWaiter:
+    def get_waiter(self, waiter_name: InstanceInServiceWaiterName) -> InstanceInServiceWaiter:
         """
         [Waiter.InstanceInService documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/elb.html#ElasticLoadBalancing.Waiter.InstanceInService)
         """
